==> editordedocumento-2.2.0-sources.jar: editor/docx/rodape/AdicionaNotaDeRodape.java <==
package editor.docx.rodape;

import org.apache.poi.xwpf.usermodel.XWPFFooter;
import org.apache.poi.xwpf.usermodel.XWPFParagraph;
import org.apache.poi.xwpf.usermodel.XWPFRun;

import java.util.List;
import java.util.Optional;

public class AdicionaNotaDeRodape {

    private String notaParaAdicionar;
    private Optional<AlinhamentoDaNotaDeRodape> alinhamentoDaNotaDeRodape;

    private AdicionaNotaDeRodape(String notaParaAdicionar, Optional<AlinhamentoDaNotaDeRodape> alinhamentoDaNotaDeRodape) {
        this.notaParaAdicionar = notaParaAdicionar;
        this.alinhamentoDaNotaDeRodape = alinhamentoDaNotaDeRodape;
    }

    public static AdicionaNotaDeRodape comNotaDeRodape(String notaParaAdicionar, Optional<AlinhamentoDaNotaDeRodape> alinhamentoDaNotaDeRodape) {
        return new AdicionaNotaDeRodape(notaParaAdicionar, alinhamentoDaNotaDeRodape);
    }

    public void adicionarNotaNosRodapes(List<XWPFFooter> rodapesDoDocumento) {
        rodapesDoDocumento.forEach(rodape -> adicionarNotaRodape(rodape));
    }

    private void adicionarNotaRodape(XWPFFooter rodape) {
        if (rodape.getListParagraph() != null) {
            XWPFParagraph paragraph = rodape.createParagraph();
            configurarAlinhamentoDaNota(paragraph);
            XWPFRun run = paragraph.createRun();
            run.addBreak();
            run.setText(this.notaParaAdicionar);
        }
    }

    private void configurarAlinhamentoDaNota(XWPFParagraph paragraph) {
        if (this.alinhamentoDaNotaDeRodape.isPresent()) {
            paragraph.setAlignment(this.alinhamentoDaNotaDeRodape.get().getAlinhamento());
        }
    }
}

==> editordedocumento-2.2.1-sources.jar: editor/docx/rodape/AdicionaNotaDeRodape.java <==
package editor.docx.rodape;

import org.apache.poi.xwpf.model.XWPFHeaderFooterPolicy;
import org.apache.poi.xwpf.usermodel.XWPFDocument;
import org.apache.poi.xwpf.usermodel.XWPFFooter;
import org.apache.poi.xwpf.usermodel.XWPFParagraph;
import org.apache.poi.xwpf.usermodel.XWPFRun;

import java.io.IOException;
import java.util.Collections;
import java.util.Hashtable;
import java.util.List;
import java.util.Optional;

public class AdicionaNotaDeRodape {

    private String notaParaAdicionar;
    private Optional<AlinhamentoDaNotaDeRodape> alinhamentoDaNotaDeRodape;

    private AdicionaNotaDeRodape(String notaParaAdicionar, Optional<AlinhamentoDaNotaDeRodape> alinhamentoDaNotaDeRodape) {
        this.notaParaAdicionar = notaParaAdicionar;
        this.alinhamentoDaNotaDeRodape = alinhamentoDaNotaDeRodape;
    }

    public static AdicionaNotaDeRodape comNotaDeRodape(String notaParaAdicionar, Optional<AlinhamentoDaNotaDeRodape> alinhamentoDaNotaDeRodape) {
        return new AdicionaNotaDeRodape(notaParaAdicionar, alinhamentoDaNotaDeRodape);
    }

    public void adicionarNotaNosRodapes(XWPFDocument documentoDocx) throws IOException {
        List<XWPFFooter> rodapesDoDocumento = obterRodapesDoDocumento(documentoDocx);
        rodapesDoDocumento.forEach(rodape -> adicionarNotaRodape(rodape));
    }

    private List<XWPFFooter> obterRodapesDoDocumento(XWPFDocument documentoDocx) throws IOException {
        List<XWPFFooter> rodapesDoDocumento = documentoDocx.getFooterList();
        if (rodapesDoDocumento.isEmpty()) {
            rodapesDoDocumento = Collections.singletonList(documentoDocx.createHeaderFooterPolicy().createFooter(XWPFHeaderFooterPolicy.DEFAULT));
        }
        return rodapesDoDocumento;
    }

    private void adicionarNotaRodape(XWPFFooter rodape) {
        if (rodape.getListParagraph() != null) {
            XWPFParagraph paragraph = rodape.createParagraph();
            configurarAlinhamentoDaNota(paragraph);
            XWPFRun run = paragraph.createRun();
            run.addBreak();
            run.setText(this.notaParaAdicionar);
        }
    }

    private void configurarAlinhamentoDaNota(XWPFParagraph paragraph) {
        if (this.alinhamentoDaNotaDeRodape.isPresent()) {
            paragraph.setAlignment(this.alinhamentoDaNotaDeRodape.get().getAlinhamento());
        }
    }
}
